==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 qoşması sistem ilə uyğun deyil.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Söndürüldü</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klaviatura qatı əlavə etmək</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarix və vaxt</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 saat vaxt formatı</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 saat vaxt formatı</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Vaxt ayarları</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Şəbəkəni açmaq</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Şəbəkəni söndürmək</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Şəbəkə ayarları</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 elementi boşaltmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Bu əməliyyat bərpa edilə bilməz</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Naməlum cihaz</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Naməlum həcm</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Hamısını çıxartmaq</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Başladıcı</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Müasir rejim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Səmərəli rejim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Yuxarı</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Görünsün</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Gizlədilsin</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ağıllı gizlətmə</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Rejim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Yerləşmə</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyəti</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Qoşmalar</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Çoxtapşırıqlı görünüş</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayırmaq</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Simli bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Simli bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Simsiz bağlantını söndürmək</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Simsiz bağlantını qoşmaq</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Şəbəkəni söndürmək</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Şəbəkəni qoşmaq</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Şəbəkə ayarları</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Cihaz söndürülüb</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Simsiz bağlantı: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Simli bağlantı: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Qoşulmayıb</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanılır</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Qoşulub, lakin internetə giriş yoxdur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Şəbəkə kabeli çıxarılıb</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Qoşulma alınmadı</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Simli şəbəkə</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>%1 Simli şəbəkəsi</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klaviaturası</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tənzimləmələr</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Elektrik qidalanması</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Tutum %1, %2 dəq qalır</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Tutum %1, %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Yükləndi</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Tutum %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Yüklənmə %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Tutum %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Tutum %1, tam yükləndi</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Masaüstünü göstərin</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayırmaq</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Elektrik qidalanması</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sistemi söndür</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözlət</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilidləmək</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Hesabı dəyişmək</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Avadanlıq</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Susdurmaq</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Səssiz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Səs ayarları</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Səs %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Səs</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Zibil Qutusu</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Səbət - %1 fayl</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Səbət - %1 fayl</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Boş</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Sistem çubuğu</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Simsiz şəbəkə</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Simsiz şəbəkə %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 qoşması sistem ilə uyğun deyil.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Təyyarə rejimi aktiv edildi</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Təyyarə rejimi ayarları</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Təyyarə rejimi söndürülüb</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Təyyarə rejimi</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Silmək</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 qoşuldu</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Qoşulur...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Söndürüldü</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klaviatura qatı əlavə etmək</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarix və vaxt</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 saat vaxt formatı</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 saat vaxt formatı</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Vaxt ayarları</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Bazar ertəsi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Çərşənbə axşamı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çərşənbə</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Cümə axşamı</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cümə</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Şənbə</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Bazar</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>bazar ertəsi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>çərşənbə axşamı</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>çərşənbə</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>cümə axşamı</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>cümə</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>şənbə</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>bazar</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation>%1il%2ay%3gün</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 elementi boşaltmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Bu əməliyyat bərpa edilə bilməz</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Naməlum cihaz</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Naməlum həcm</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Hamısını çıxartmaq</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Başladıcı</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Təhlükəsiz rejimdən çıxın</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dok - Təhlükəsiz rejim</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Dok təhlükəsiz rejimdədir, onun düzgün göstərilməsi üçün çıxın</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Müasir rejim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Səmərəli rejim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Yuxarı</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Görünsün</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Gizlədilsin</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ağıllı gizlətmə</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Rejim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Yerləşmə</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyəti</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Dok panel ayarları</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Ölçü</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Çoxsaylı ekran</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Plaqin sahəsi</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Dok paneldə görünəcək nişanları seçin</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Müasir rejim</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Səmərəli rejim</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Rejim</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Yuxarıda</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Aşağıda</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Yerləşmə</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Görünsün</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Gizli qalsın</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Ağıllı gizlənmə</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyəti</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Kiçik</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Geniş</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dok paneli göstərmək</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Kursorun olduğu ekranda</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Yalnız əsas ekranda</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Çoxtapşırıqlı görünüş</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayırmaq</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klaviaturası</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tənzimləmələr</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Elektrik qidalanması</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Tutum %1, %2 dəq qalır</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Tutum %1, %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 dəq qalır</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Yüklənmə %1, dolmağa %2 saat %3 dəq qalır</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Tutum %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Yüklənmə %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Tutum %1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Tutum %1, tam yükləndi</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Dok panel</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Rejim</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Yerləşmə</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Vəziyyəti</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Ölçü</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dok paneli göstərmək</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Plaqin sahəsi</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Masaüstünü göstərin</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayırmaq</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Elektrik qidalanması</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sistemi söndür</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözlət</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilidləmək</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Hesabı dəyişmək</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Elektrik enerjisi ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Səs səviyyəsi</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Susdurmaq</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Səssiz</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Səs ayarları</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Səs %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Çıxış cihazı tapılmadı</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Səs</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Zibil Qutusu</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Səbət - %1 fayl</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Səbət - %1 fayl</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Zibil qutusuna daşı</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Boş</translation>
    </message>
</context>
</TS>
